#!/usr/bin/env python
# coding: utf-8
import value_tagrec.sim as sim

def tagrec(textStr, tagLevel=3, top=5, confidenceLowerBound=0):
    return sim.execute(textStr, tagLevel, top, confidenceLowerBound)


if __name__ == '__main__':

#     textStr = "《习近平关于中国特色大国外交论述摘编》出版发行\n \
# 　　新华社北京1月5日电  中共中央党史和文献研究院编辑的《习近平关于中国特色大国外交论述摘编》一书，近日由中央文献出版社出版，在全国发行。\n \
# 　　党的十八大以来，在以习近平同志为核心的党中央坚强领导下，面对国际形势风云变幻，我们开创性推进中国特色大国外交，我国对外工作砥砺前行、波澜壮阔，取得了历史性成就。习近平总书记深刻把握新时代中国和世界发展大势，在对外工作上进行一系列重大理论和实践创新，形成了习近平外交思想。习近平外交思想，是习近平新时代中国特色社会主义思想的重要组成部分，对于坚持党对外事工作的集中统一领导，统筹国内国际两个大局，牢牢把握服务民族复兴、促进人类进步这条主线，坚定维护国家主权、安全、发展利益，推动构建人类命运共同体，努力开创中国特色大国外交新局面，具有十分重要的指导意义。\n \
# 　　《论述摘编》共分10个专题：坚持以维护党中央权威为统领加强党对对外工作的集中统一领导；坚持以实现中华民族伟大复兴为使命推进中国特色大国外交；坚持以维护世界和平、促进共同发展为宗旨推动构建人类命运共同体；坚持以中国特色社会主义为根本增强战略自信；坚持以共商共建共享为原则推动“一带一路”建设；坚持以相互尊重、合作共赢为基础走和平发展道路；坚持以深化外交布局为依托打造全球伙伴关系；坚持以公平正义为理念引领全球治理体系改革；坚持以国家核心利益为底线维护国家主权、安全、发展利益；坚持以对外工作优良传统和时代特征相结合为方向塑造中国外交独特风范。书中收入504段论述，摘自习近平总书记2012年12月至2019年11月期间的讲话、谈话、报告、演讲、文章、贺信等190多篇重要文献。其中部分论述是第一次公开发表。\n"
#
    textStr = "全心全意为增强人民群众获得感、幸福感、安全感而努力工作"
    tagrec(textStr)


#!/usr/bin/env python
# coding: utf-8
class Word:
    """
    用于帮助建立Words.json
    """
    name = ""
    level = -1 #该词属于第几层节点
    wordID = -1
    word1level = None
    word2level = None
    word3level = None
    word4level = None
    baseIinterpretation = None
    synonym = None#近义词
    antonym = None#反义词
    sentence = None#例句
    url = None#抽取近反义词新的的网页
    source = None#抽取近反义词信息网站的主页
    docURLs = None#种子文档对应的网页链接list
    docs = None#种子文档对应的download下来的文本dict，{序号：{见下}， 序号：{见下}}
    # docID:1,会在data/docs会存在一个1.txt的原始内容文档，和一个1_extract.txt抽取到的文档--int
    # docURL,爬取该文档的url: docID:url--""
    # docTitle:单独爬取出来的新闻标题--""
    # docSentences：抽取出的文档内容，按段划分，每篇文档一个list，包含标题+正文内容--[]
    # docCode：网页的编码方式--""

    def __init__(self, name, level=None, wordID=None,
                 word1level=None, word2level=None, word3level=None, word4level = None,
                 baseIinterpretation = None, synonym = None, antonym = None, sentence = None,
                 url=None, source = None, docURLs = None, docs=None):
        """
        初始化创建类
        """
        self.name = name
        self.level = level
        self.wordID = wordID
        self.word1level = word1level
        self.word2level = word2level
        self.word3level = word3level
        self.word4level = word4level
        self.baseIinterpretation = baseIinterpretation
        self.synonym = synonym
        self.antonym = antonym
        self.sentence = sentence
        self.url = url
        self.source = source
        self.docURLs = docURLs
        self.docs = docs


    def getFatherName(self):
        """
        获取当前节点的直接父节点Name
        :return:
        """
        if self.level == 1:
            return None
        elif self.level == 2:
            return self.word1level
        elif self.level == 3:
            return self.word2level
        elif self.level == 4:
            return self.word3level
        return None

    def getChildrensList(self):
        """
        获取当前节点的直接子节点list,
        注意，第四层节点的 子节点list为空
        :return:
        """
        if self.level == 1:
            return self.word2level
        elif self.level == 2:
            return self.word3level
        elif self.level == 3:
            return self.word4level
        elif self.level == 4:
            return None
        return None

    def printSynonym(self):
        """
        返回要打印格式的近义词列表
        :return:
        """
        if self.level != 4:
            return ""
        return '；'.join(self.synonym)

    def printAntonym(self):
        """
        返回要打印格式的反义词列表
        :return:
        """
        if self.level != 4:
            return ""
        return '；'.join(self.antonym)

    def printBaseIinterpretation(self):
        """
        返回要打印格式的基本释义
        :return:
        """
        if self.level != 4:
            return ""
        return ' '.join(self.baseIinterpretation)

    def printSentence(self):
        """
        返回要打印格式的例句
        :return:
        """
        if self.level != 4:
            return ""
        return ' '.join(self.sentence)

    def printDocURLs(self):
        """
        返回要打印格式的种子文档对应的urls，一个一行
        :return:
        """
        if self.level != 4:
            return ""
        return '\n'.join(self.docURLs)

    def printNameAndLevel(self):
        """
        返回要打印格式的name和level
        :return:
        """
        return self.name + "。位于知识图谱第" + str(self.level) + "层"

    def printFather(self):
        """
        返回要打印格式的father
        :return:
        """
        return "父节点：" + self.getFatherName()

    def printChildrens(self):
        """
        返回要打印格式的children
        :return:
        """
        return "子节点：" + '；'.join(self.getChildrensList())

    def printWordList(self):
        """
        输出该节点的所有信息
        :return: list形式
        """
        wordList = []
        wordList.append(self.printNameAndLevel())
        if self.level == 1:
            wordList.append(self.printChildrens())
        elif self.level == 2:
            wordList.append(self.printFather())
            wordList.append(self.printChildrens())
        elif self.level == 3:
            wordList.append("第一层节点" + self.word1level)
            wordList.append(self.printFather())
            wordList.append(self.printChildrens())
        elif self.level == 4:
            wordList.append("第一层节点" + self.word1level)
            wordList.append("第二层节点" + self.word2level)
            wordList.append(self.printFather())
            wordList.append("基本释义: " + self.printBaseIinterpretation())
            wordList.append("近义词: " + self.printSynonym())
            wordList.append("反义词: " + self.printAntonym())
            wordList.append("例句: " + self.printSentence())
            wordList.append("核心文档网址: \n" + self.printDocURLs())
        return wordList

    def printWord(self):
        """
        输出该节点。包括根->父节点->本身节点,用 / 分割，低等级在前，高等级在后
        :return:
        """
        if self.level == 1:
            return self.name
        if self.level == 2:
            return self.name + '/' + self.word1level
        if self.level == 3:
            return self.name + '/' + self.word2level + '/' + self.word1level
        if self.level == 4:
            return self.name+ '/' + self.word3level+ '/' + self.word2level + '/'+self.word1level
        return None

    def toDict(self):
        """
        将该节点转换为字典，不同level转换后需要的信息不同
        :return:
        """
        dic = {"name":self.name, "level":self.level, "wordID":self.wordID,
               "word1level":self.word1level, "word2level":self.word2level,
               "word3level":self.word3level, "word4level":self.word4level,
               "baseIinterpretation":self.baseIinterpretation, "synonym":self.synonym, "antonym":self.antonym,
               "sentence":self.sentence, "url":self.url, "source":self.source, "docURLs": self.docURLs,
               "docs":self.docs}
        return dic

    def toDictAttr(self):
        """
        将该节点转换为字典
        :return:
        """
        dic = {"name":self.name, "wordID":self.wordID,
               "baseIinterpretation":self.baseIinterpretation, "synonym":self.synonym, "antonym":self.antonym,
               "sentence":self.sentence, "url":self.url, "source":self.source, "docURLs": self.docURLs,
               "docs":self.docs}
        return dic

